package
module
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Sep 18, 2025
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
README
¶

Fix - Test fixtures made easy!
-
Fixtures are being evaluated only once per test (*testing.T), no matter how many times they're being called
-
Fixtures resolve their dependencies
-
Zero dependencies
-
Inspired by pytest
Examples
See the examples folder and fixture_test.go
Documentation
¶
type Fixture[V any] interface {
Value(t *testing.T) V
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.